@@ -10,7 +10,7 @@ use CGI::OptimalQuery::EmailMergeTool();
 
 chdir "$Bin/..";
 
-my $dbh = DBI->connect("dbi:SQLite:dbname=db/dat.db","","");
+my $dbh = DBI->connect("dbi:SQLite:dbname=db/dat.db","","", { RaiseError => 1, PrintError => 1 });
 
 my %schema = (
   'dbh' => $dbh,
