@@ -225,9 +225,14 @@ if (! window._OQAjaxQueryLoaded)
     if (rv >= 24) rv = 23;
     return rv;
   };
-  $(document).delegate('.OQSaveReportBut', 'click', function(e) {
+
+  $(document).on('click','.OQSaveNewReportBut,.OQSaveReportBut', function(e) {
     var $f = $('.OQform');
     var dat = buildParamMap($f);
+
+    // if request to save new saved search
+    if ($(this).hasClass('OQSaveNewReportBut')) dat.OQss='';
+
     dat.module = 'InteractiveQuery2Tools';
     dat.OQsaveSearchTitle = $("#OQsaveSearchTitle").val();
     if (! dat.OQsaveSearchTitle) {
@@ -542,9 +547,7 @@ if (! window._OQAjaxQueryLoaded)
     var dat = buildParamMap($f);
     delete dat.show; delete dat.sort; delete dat.page; delete dat.rows_page;
     delete dat.on_select; delete dat.queryDescr;
-    if (dat.filter) dat.filter += ' AND ';
-    else dat.filter = '';
-    dat.filter += '['+colalias+'] contains ""';
+    dat.field = colalias;
     dat.module = 'InteractiveFilter2';
     $.ajax({ url: $f[0].action, type: 'POST', data: dat, dataType: 'html',
       context: $f,
